@@ -181,6 +181,11 @@ def create_or_edit_object__post_handler(*, form, is_create, **_):
     if is_create:
         assert form.instance is None
         form.instance = evaluate(form.extra.new_instance, **form.iommi_evaluate_parameters())
+
+        # `own_evaluate_parameters` can't be used here because it is calculated too early when the instance doesn't exist yet. So instead we have to insert it manually when we get it.
+        # noinspection PyProtectedMember
+        form._evaluate_parameters['instance'] = form.instance
+
         for field in values(
             form.fields
         ):  # two phase save for creation in django, have to save main object before related stuff
@@ -194,9 +199,9 @@ def create_or_edit_object__post_handler(*, form, is_create, **_):
         return
 
     if is_create:  # two phase save for creation in django...
-        form.extra.pre_save_all_but_related_fields(instance=form.instance, **form.iommi_evaluate_parameters())
+        form.extra.pre_save_all_but_related_fields(**form.iommi_evaluate_parameters())
         form.instance.save()
-        form.extra.on_save_all_but_related_fields(instance=form.instance, **form.iommi_evaluate_parameters())
+        form.extra.on_save_all_but_related_fields(**form.iommi_evaluate_parameters())
 
     form.apply(form.instance)
 
@@ -207,13 +212,13 @@ def create_or_edit_object__post_handler(*, form, is_create, **_):
     if form.is_valid():
         attributes = filter(None, [f.attr for f in form.fields.values()])
 
-        form.extra.pre_save(instance=form.instance, **form.iommi_evaluate_parameters())
+        form.extra.pre_save(**form.iommi_evaluate_parameters())
         for prefix in find_unique_prefixes(attributes):
             model_object = form.instance
             if prefix:  # Might be ''
                 model_object = getattr_path(model_object, prefix)
             model_object.save()
-        form.extra.on_save(instance=form.instance, **form.iommi_evaluate_parameters())
+        form.extra.on_save(**form.iommi_evaluate_parameters())
 
         return create_or_edit_object_redirect(
             is_create, form.extra.redirect_to, form.get_request(), form.extra.redirect, form
@@ -306,6 +311,7 @@ def choice_queryset__extra__model_from_choices(form, field, choices):
 
 
 def choice_queryset__extra__filter_and_sort(field, value, **_):
+    assert field.search_fields is not None, f'There are no search_fields specified for {field._name}'
     if not value:
         return field.choices.order_by(*field.search_fields)
 
@@ -764,7 +770,11 @@ class Field(Part, Tag):
                 value = self._validate_parsed_data(self.parsed_data)
 
         if not self.errors:
-            if form.mode is FULL_FORM_FROM_REQUEST and self.required and value in [None, '']:
+            if (
+                form.mode is FULL_FORM_FROM_REQUEST
+                and self.required
+                and (value == [] if self.is_list else value in [None, ''])
+            ):
                 self.add_error('This field is required')
             else:
                 self.value = value
@@ -1225,10 +1235,16 @@ def create_or_edit_object_redirect(is_create, redirect_to, request, redirect, fo
 
 def delete_object__post_handler(form, **_):
     instance = form.instance
-    form.extra.on_delete(instance=form.instance, **form.iommi_evaluate_parameters())
+    form.extra.on_delete(**form.iommi_evaluate_parameters())
     if instance.pk is not None:  # Check if already deleted by the callback
         instance.delete()
-    return HttpResponseRedirect('../..')
+    return create_or_edit_object_redirect(
+        is_create=False,
+        redirect_to=form.extra.redirect_to,
+        request=form.get_request(),
+        redirect=form.extra.redirect,
+        form=form,
+    )
 
 
 # noinspection PyUnreachableCode
@@ -1432,6 +1448,9 @@ class Form(Part):
         if self.instance is None and self.parent_form is not None and self.parent_form.instance is not None:
             self.instance = self.read_nested_form_from_instance(self, self.parent_form.instance)
 
+        self._evaluate_parameters['instance'] = self.instance
+        self.editable = evaluate_strict(self.editable, **self.iommi_evaluate_parameters())
+
         self.title = evaluate_strict(self.title, **self.iommi_evaluate_parameters())
         build_and_bind_h_tag(self)
 
@@ -1455,7 +1474,7 @@ class Form(Part):
         self.validate()
 
     def own_evaluate_parameters(self):
-        return dict(form=self)
+        return dict(form=self, instance=self.instance)
 
     @property
     def is_nested_form(self) -> bool:
@@ -1591,7 +1610,7 @@ class Form(Part):
         for field in values(self.fields):
             self.apply_field(instance=instance, field=field)
         for nested_form in values(self.nested_forms):
-            nested_form.write_nested_form_to_instance(nested_form, instance)
+            nested_form.write_nested_form_to_instance(form=nested_form, instance=instance)
 
         return instance
 
