@@ -26,6 +26,7 @@ from iommi.base import (
     NOT_BOUND_MESSAGE,
 )
 from iommi.debug import (
+    get_instantiated_at_info,
     iommi_debug_on,
 )
 from iommi.endpoint import (
@@ -88,7 +89,8 @@ class Part(Traversable):
         if iommi_debug_on():
             import inspect
 
-            self._instantiated_at_frame = inspect.currentframe().f_back
+            frame = inspect.currentframe()
+            self._instantiated_at_info = get_instantiated_at_info(frame.f_back)
 
     @dispatch(
         render=EMPTY,
@@ -157,7 +159,9 @@ class Part(Traversable):
             if request.method == 'POST':
                 assert False, 'This request was a POST, but there was no dispatch command present.'
 
-        return HttpResponse(render_root(part=self, **kwargs))
+        response = HttpResponse(render_root(part=self, **kwargs))
+        response.iommi_part = self
+        return response
 
     def iommi_collected_assets(self):
         return sort_after(self.iommi_root()._iommi_collected_assets)
