@@ -333,6 +333,13 @@ class Filter(Part):
     def text(cls, call_target=None, **kwargs):
         return call_target(**kwargs)
 
+    @classmethod
+    @class_shortcut(
+        call_target__attribute='text',
+    )
+    def textarea(cls, call_target=None, **kwargs):
+        return call_target(**kwargs)
+
     @classmethod
     @class_shortcut(
         query_operator_to_q_operator=case_sensitive_query_operator_to_q_operator,
@@ -942,7 +949,7 @@ class Query(Part):
                 f'Unknown filter "{query_name}", available filters: {list(keys(self.filter_name_by_query_name))}'
             )
 
-        filter = self.filters.get(filter_name.lower())
+        filter = self._lowercase_filters().get(filter_name.lower())
         if filter is None:
             raise QueryException(
                 f'Unknown filter "{query_name}", available filters: {list(keys(self.filter_name_by_query_name))}'
@@ -1044,6 +1051,11 @@ class Query(Part):
             self.query_error = str(e)
             raise
 
+    def _lowercase_filters(self):
+        if not hasattr(self, '_lowercase_filters_cache'):
+            self._lowercase_filters_cache = {k.lower(): v for k, v in items(self.filters)}
+        return self._lowercase_filters_cache
+
     @classmethod
     @dispatch(
         filters=EMPTY,
