@@ -8,6 +8,19 @@ from iommi.style_font_awesome_4 import font_awesome_4
 foundation_base = Style(
     base,
     font_awesome_4,
+    sub_styles__horizontal=dict(
+        Form__attrs__class={},
+        Field=dict(
+            shortcuts=dict(
+                boolean__attrs__class={'medium-2': True, 'medium-4': False},
+                boolean_tristate__attrs__class={'medium-2': True, 'medium-4': False},
+            ),
+            attrs__class={
+                'medium-4': True,
+                'cell': True,
+            },
+        ),
+    ),
     root__assets=dict(
         css=Asset.css(
             attrs=dict(
@@ -52,7 +65,7 @@ foundation_base = Style(
         ),
     ),
     Query=dict(
-        form__iommi_style='foundation_horizontal',
+        form__iommi_style='horizontal',
         form_container=dict(
             tag='span',
             attrs__class={
@@ -75,19 +88,3 @@ foundation_base = Style(
 foundation = Style(
     foundation_base,
 )
-
-foundation_horizontal = Style(
-    foundation_base,
-    internal=True,
-    Form__attrs__class={},
-    Field=dict(
-        shortcuts=dict(
-            boolean__attrs__class={'medium-2': True, 'medium-4': False},
-            boolean_tristate__attrs__class={'medium-2': True, 'medium-4': False},
-        ),
-        attrs__class={
-            'medium-4': True,
-            'cell': True,
-        },
-    ),
-)
