@@ -5,7 +5,8 @@ from iommi.style_font_awesome_4 import font_awesome_4
 test = Style(
     base,
     font_awesome_4,
-    assets=dict(
+    internal=True,
+    root__assets=dict(
         jquery=None,
         select2_js=None,
         select2_css=None,
@@ -13,8 +14,7 @@ test = Style(
         axios=None,
     ),
     Field=dict(
-        shortcuts=dict(
-        ),
+        shortcuts=dict(),
     ),
     Table=dict(
         attrs__class__table=True,
@@ -25,10 +25,7 @@ test = Style(
     Paginator=dict(
         template='iommi/table/bootstrap/paginator.html',
     ),
-    Menu=dict(
-        tag='nav',
-        items_container__tag='ul'
-    ),
+    Menu=dict(tag='nav', items_container__tag='ul'),
     MenuItem=dict(
         tag='li',
         a__attrs__class={'link': True},
