@@ -693,6 +693,13 @@ class Column(Part):
     def text(cls, call_target, **kwargs):
         return call_target(**kwargs)
 
+    @classmethod
+    @class_shortcut(
+        call_target__attribute='text',
+    )
+    def textarea(cls, call_target, **kwargs):
+        return call_target(**kwargs)
+
     @classmethod
     @class_shortcut
     def link(cls, call_target, **kwargs):
@@ -1073,23 +1080,36 @@ def bulk__post_handler(table, form, **_):
             continue
 
         if isinstance(field.model_field, ManyToManyField):
+            assert '__' not in field.attr, "Nested m2m relations is currently not supported for bulk editing"
             m2m_updates.append(field)
         else:
             simple_updates.append(field)
 
     updates = {field.attr: field.value for field in simple_updates}
-    queryset.update(**updates)
+    m2m_updates = {field.attr: field.value for field in m2m_updates}
+
+    pks = list(queryset.values_list('pk', flat=True))
+
+    queryset.model.objects.filter(pk__in=pks).update(**updates)
 
     if m2m_updates:
         for obj in queryset:
-            for field in m2m_updates:
-                assert '__' not in field.attr, "Nested m2m relations is currently not supported for bulk editing"
-                getattr(obj, field.attr).set(field.value)
+            for attr, value in items(m2m_updates):
+                getattr(obj, attr).set(value)
             obj.save()
 
-    table.post_bulk_edit(queryset=queryset, updates=updates, **table.iommi_evaluate_parameters())
+    response = table.post_bulk_edit(
+        pks=pks,
+        queryset=queryset,
+        updates=updates,
+        m2m_updates=m2m_updates,
+        **table.iommi_evaluate_parameters(),
+    )
 
-    return HttpResponseRedirect(form.get_request().META['HTTP_REFERER'])
+    if response is not None:
+        return response
+
+    return HttpResponseRedirect(form.get_request().META.get('HTTP_REFERER', '/'))
 
 
 def bulk_delete__post_handler(table, form, **_):
@@ -1134,7 +1154,7 @@ def bulk_delete__post_handler(table, form, **_):
 
     if request.POST.get(p.parts.confirm.bulk.fields.confirmed.iommi_path) == 'confirmed':
         queryset.delete()
-        return HttpResponseRedirect(form.get_request().META['HTTP_REFERER'])
+        return HttpResponseRedirect(form.get_request().META.get('HTTP_REFERER', '/'))
 
     return HttpResponse(render_root(part=p))
 
@@ -1443,7 +1463,7 @@ class Table(Part, Tag):
         query_class = Query
         action_class = Action
         page_class = Page
-        endpoints__tbody__func = lambda table, **_: {'html': table.__html__(template='iommi/table/table_tag.html')}
+        endpoints__tbody__func = lambda table, **_: {'html': table.__html__(template='iommi/table/table_container.html')}
         endpoints__csv__func = endpoint__csv
 
         attrs = Namespace(
@@ -1596,7 +1616,7 @@ class Table(Part, Tag):
         # In bind initial_rows will be used to set these 3 (in that order)
         self.sorted_rows = None
         self.sorted_and_filtered_rows = None
-        self._visible_rows = None
+        self.visible_rows = None
 
         collect_members(self, name='actions', items=actions, cls=self.get_meta().action_class)
         collect_members(self, name='columns', items=columns, items_dict=_columns_dict, cls=self.get_meta().member_class)
@@ -1734,34 +1754,10 @@ class Table(Part, Tag):
     def div(cls, call_target=None, **kwargs):
         return call_target(**kwargs)
 
-    @property
-    def rows(self):
-        """Legacy API: if self is fully bound return the rows that are
-        displayed on the screen. Otherwise return as far as we got
-        in the refinement process from initial_rows -> visible_rows.
-
-        You are probably better off using `visible_rows` or
-        `initial_rows` directly.
-        """
-        if self._visible_rows is not None:
-            return self._visible_rows
-        if self.sorted_and_filtered_rows is not None:
-            return self.sorted_and_filtered_rows
-        if self.sorted_rows is not None:
-            return self.sorted_rows
-        return self.initial_rows
-
     @property
     def paginator(self):
         return self.parts.page
 
-    @property
-    def visible_rows(self):
-        if self._visible_rows is None:
-            self._visible_rows = self.parts.page.rows
-
-        return self._visible_rows
-
     def on_bind(self) -> None:
         bind_members(self, name='actions', cls=Actions)
         bind_members(self, name='columns')
@@ -1786,6 +1782,7 @@ class Table(Part, Tag):
         if isinstance(self.initial_rows, QuerySet):
             # Copy the QuerySet so we don't get the original QuerySets result cache
             self.initial_rows = self.initial_rows.all()
+            self.rows = self.initial_rows
 
         self._prepare_sorting()
 
@@ -1826,16 +1823,23 @@ class Table(Part, Tag):
             ]
             if prefetch:
                 self.sorted_and_filtered_rows = self.sorted_and_filtered_rows.prefetch_related(*prefetch)
+                self.rows = self.sorted_and_filtered_rows
             if select:
                 self.sorted_and_filtered_rows = self.sorted_and_filtered_rows.select_related(*select)
+                self.rows = self.sorted_and_filtered_rows
 
         self.bulk_container = self.bulk_container.bind(parent=self)
 
+    def get_visible_rows(self):
+        self.visible_rows = self.parts.page.rows
+        return self.visible_rows
+
     def _bind_query(self):
         """
         Bind the query form and apply it.
         """
         self.sorted_and_filtered_rows = self.sorted_rows
+        self.rows = self.sorted_and_filtered_rows
 
         if self.query is None:
             return
@@ -1856,8 +1860,10 @@ class Table(Part, Tag):
             self.sorted_and_filtered_rows = self.query.filter(
                 query=self.query, rows=self.sorted_rows, **self.iommi_evaluate_parameters()
             )
+            self.rows = self.sorted_and_filtered_rows
         else:
             self.sorted_and_filtered_rows = self.sorted_rows
+            self.rows = self.sorted_and_filtered_rows
 
     def _bind_bulk_form(self):
         if self.bulk is None:
@@ -1900,7 +1906,7 @@ class Table(Part, Tag):
     def _prepare_auto_rowspan(self):
         auto_rowspan_columns = [column for column in values(self.columns) if column.auto_rowspan]
         if auto_rowspan_columns:
-            self._visible_rows = list(self.visible_rows)
+            self.visible_rows = list(self.get_visible_rows())
             no_value_set = object()
             for column in auto_rowspan_columns:
                 if column.cell.attrs.get('rowspan', no_value_set) is not no_value_set:
@@ -1939,6 +1945,7 @@ class Table(Part, Tag):
         # TODO: Sorting less values is faster then sorting more values, so we should
         # filter first and then sort.
         self.sorted_rows = self.initial_rows
+        self.rows = self.sorted_rows
         request = self.get_request()
         if request is None:
             return
@@ -1957,9 +1964,11 @@ class Table(Part, Tag):
             if sort_column.sortable:
                 if isinstance(self.initial_rows, list):
                     self.sorted_rows = ordered_by_on_list(self.initial_rows, order_args[0], is_desc)
+                    self.rows = self.sorted_rows
                 else:
                     order_args = ["%s%s" % (is_desc and '-' or '', x) for x in order_args]
                     self.sorted_rows = self.initial_rows.order_by(*order_args)
+                    self.rows = self.sorted_rows
 
     def _bind_headers(self):
         prepare_headers(self)
@@ -2014,7 +2023,7 @@ class Table(Part, Tag):
     def cells_for_rows(self):
         """Yield a Cells instance for each visible row on the screen."""
         assert self._is_bound, NOT_BOUND_MESSAGE
-        rows = self.preprocess_rows(rows=self.visible_rows, **self.iommi_evaluate_parameters())
+        rows = self.preprocess_rows(rows=self.get_visible_rows(), **self.iommi_evaluate_parameters())
         for i, row in enumerate(rows):
             row = self.preprocess_row(table=self, row=row)
             yield Cells(row=row, row_index=i, **self.row.as_dict()).bind(parent=self)
@@ -2067,7 +2076,7 @@ class Table(Part, Tag):
                 return self.sorted_and_filtered_rows.filter(pk__in=identifiers)
             else:
                 identifiers = frozenset([int(i) for i in identifiers])
-                return [row for ndx, row in enumerate(self.visible_rows) if ndx in identifiers]
+                return [row for ndx, row in enumerate(self.get_visible_rows()) if ndx in identifiers]
 
     def bulk_queryset(self):
         """Return the queryset that contains only the selected rows with
@@ -2089,12 +2098,12 @@ class Table(Part, Tag):
 
         self._prepare_auto_rowspan()
 
-        assert self.visible_rows is not None
+        assert self.get_visible_rows() is not None
 
         context = self.iommi_evaluate_parameters().copy()
 
         if self.query and self.query.form and not self.query.form.is_valid():
-            self._visible_rows = []
+            self.visible_rows = []
             self.paginator.count = 0
 
         return render(request=request, template=template or self.template, context=context)
